from django.db import models
from users.models import Person
import random

class Score(models.Model):
    session = models.ForeignKey('management.Session', on_delete = models.SET_NULL, blank=True, null=True)
    semester = models.ForeignKey('management.Semester', on_delete = models.SET_NULL, blank=True, null=True)
    course = models.ForeignKey('management.Course', on_delete=models.SET_NULL, null=True, blank=True, related_name='result_course')
    poster = models.ForeignKey('users.Person', on_delete = models.SET_NULL, null=True, related_name="score_poster")
    static_lecturer = models.ForeignKey('users.Person', on_delete=models.SET_NULL, null=True, related_name='static_lecturer', verbose_name='Lecturer')
    undergrad = models.ForeignKey('users.Person', on_delete = models.SET_NULL, null=True, related_name="undergrad_poster")
    ca1 = models.IntegerField(blank=True, null=True, verbose_name="CA")
    exam = models.IntegerField(blank=True, null=True, verbose_name="Exam")
    total = models.IntegerField(blank=True, null=True, default = 0)
    grade = models.CharField(max_length=2, blank=True, null=True)
    recorded = models.CharField(max_length=1, blank=True, null=True)
    points = models.IntegerField(blank=True, default = 0)
    credit_unit = models.IntegerField(blank=True, default = 0)
    semester_points = models.IntegerField(blank=True, default = 0)
    # semester_obtainable = models.IntegerField(blank=True, default = 0)
    total_points = models.IntegerField(blank=True, default = 0)
    # total_obtainable = models.IntegerField(blank=True, default = 0)
    semester_credits = models.IntegerField(blank=True, default = 0)
    total_credits = models.IntegerField(blank=True, default = 0)
    semester_gpa = models.DecimalField(max_digits=3, decimal_places=2, blank=True, null=True)
    cumulative_gpa = models.DecimalField(max_digits=3, decimal_places=2, blank=True, null=True)
    created = models.DateTimeField(auto_now_add=True, null=True)
    updated = models.DateTimeField(auto_now=True, null=True)
    static_level = models.CharField(max_length=20, blank=True, null=True)
    static_seal = models.ImageField(null=True, blank=True)
    static_adviser = models.ImageField(null=True, blank=True)
    static_dean = models.ImageField(null=True, blank=True)
    static_undergrad_image = models.ImageField(null=True, blank=True)

    def __str__(self):
        try:
            return str(self.undergrad.first_name) + " " + str(self.undergrad.last_name) + " " + str(self.cumulative)
        except:
            return str(self.id)

    class Meta:
        ordering = ('-created',)
        # verbose_name = "Score"
        # verbose_name_plural = "Scores"

    def grade(self):
        if self.total == None:
            return "AR"
        else:
            if self.total >= 70:
                return "A"
            elif self.total >= 60:
                return "B"
            elif self.total >= 50:
                return "C"
            elif self.total >= 45:
                return "D"
            elif self.total >= 40:
                return "E"
            elif self.total >= 0:
                return "F"

    def point(self):
        if self.total < 40:
            return 0
        elif self.total >= 40 and self.total < 45:
            return 1
        elif self.total >= 45 and self.total < 50:
            return 2
        elif self.total >= 50 and self.total < 60:
            return 3
        elif self.total >= 60 and self.total < 70:
            return 4
        else:
            return 5
